@@ -9,12 +9,10 @@ const bench = common.createBenchmark(main, {
   millions: [1]
 });
 
-function main(conf) {
-  const noAssert = conf.noAssert === 'true';
-  const len = +conf.millions * 1e6;
+function main({ noAssert, millions, type, endian, value }) {
+  noAssert = noAssert === 'true';
+  type = type || 'Double';
   const buff = Buffer.alloc(8);
-  const type = conf.type || 'Double';
-  const endian = conf.endian;
   const fn = `read${type}${endian}`;
   const values = {
     Double: {
@@ -32,15 +30,12 @@ function main(conf) {
       nan: NaN,
     },
   };
-  const value = values[type][conf.value];
 
-  buff[`write${type}${endian}`](value, 0, noAssert);
-  const testFunction = new Function('buff', `
-    for (var i = 0; i !== ${len}; i++) {
-      buff.${fn}(0, ${JSON.stringify(noAssert)});
-    }
-  `);
+  buff[`write${type}${endian}`](values[type][value], 0, noAssert);
+
   bench.start();
-  testFunction(buff);
-  bench.end(len / 1e6);
+  for (var i = 0; i !== millions * 1e6; i++) {
+    buff[fn](0, noAssert);
+  }
+  bench.end(millions);
 }
