@@ -1,7 +1,6 @@
 'use strict';
 
 const common = require('../common.js');
-const PORT = common.PORT;
 const path = require('path');
 const fs = require('fs');
 
@@ -25,7 +24,7 @@ function main({ requests, streams, clients }) {
       stream.respondWithFD(fd);
       stream.on('error', (err) => {});
     });
-    server.listen(PORT, () => {
+    server.listen(common.PORT, () => {
       bench.http({
         path: '/',
         requests,
