@@ -5,8 +5,8 @@ const bench = common.createBenchmark(main, {
   millions: [5]
 });
 
-function main(conf) {
-  const N = +conf.millions * 1e6;
+function main({ millions }) {
+  const N = millions * 1e6;
 
   process.on('exit', function() {
     bench.end(N / 1e6);
