@@ -5,8 +5,8 @@ const bench = common.createBenchmark(main, {
   thousands: [5000],
 });
 
-function main(conf) {
-  const N = +conf.thousands * 1e3;
+function main({ thousands }) {
+  const N = thousands * 1e3;
   var n = 0;
   bench.start();
   function cb() {
