@@ -139,7 +139,7 @@ function ClientRequest(options, cb) {
   var host = options.host = validateHost(options.hostname, 'hostname') ||
                             validateHost(options.host, 'host') || 'localhost';
 
-  var setHost = (options.setHost === undefined);
+  var setHost = (options.setHost === undefined || Boolean(options.setHost));
 
   this.socketPath = options.socketPath;
   this.timeout = options.timeout;
