@@ -21,15 +21,16 @@
 
 'use strict';
 
-const { ERR_CONSOLE_WRITABLE_STREAM } = require('internal/errors').codes;
+const {
+  isStackOverflowError,
+  codes: { ERR_CONSOLE_WRITABLE_STREAM },
+} = require('internal/errors');
 const util = require('util');
 const kCounts = Symbol('counts');
 
 // Track amount of indentation required via `console.group()`.
 const kGroupIndent = Symbol('groupIndent');
 
-let MAX_STACK_MESSAGE;
-
 function Console(stdout, stderr, ignoreErrors = true) {
   if (!(this instanceof Console)) {
     return new Console(stdout, stderr, ignoreErrors);
@@ -113,17 +114,9 @@ function write(ignoreErrors, stream, string, errorhandler, groupIndent) {
 
     stream.write(string, errorhandler);
   } catch (e) {
-    if (MAX_STACK_MESSAGE === undefined) {
-      try {
-        // eslint-disable-next-line no-unused-vars
-        function a() { a(); }
-      } catch (err) {
-        MAX_STACK_MESSAGE = err.message;
-      }
-    }
     // console is a debugging utility, so it swallowing errors is not desirable
     // even in edge cases such as low stack space.
-    if (e.message === MAX_STACK_MESSAGE && e.name === 'RangeError')
+    if (isStackOverflowError(e))
       throw e;
     // Sorry, there's no proper way to pass along the error here.
   } finally {
