@@ -33,8 +33,8 @@ const {
   ServerResponse
 } = require('_http_server');
 
-function createServer(requestListener) {
-  return new Server(requestListener);
+function createServer(opts, requestListener) {
+  return new Server(opts, requestListener);
 }
 
 function request(options, cb) {
