@@ -124,7 +124,7 @@ function validateAsyncId(asyncId, type) {
 // emitInitScript.
 function emitInitNative(asyncId, type, triggerAsyncId, resource) {
   active_hooks.call_depth += 1;
-  // Use a single try/catch for all hook to avoid setting up one per iteration.
+  // Use a single try/catch for all hooks to avoid setting up one per iteration.
   try {
     for (var i = 0; i < active_hooks.array.length; i++) {
       if (typeof active_hooks.array[i][init_symbol] === 'function') {
@@ -207,11 +207,15 @@ function storeActiveHooks() {
   // Don't want to make the assumption that kInit to kDestroy are indexes 0 to
   // 4. So do this the long way.
   active_hooks.tmp_fields = [];
-  active_hooks.tmp_fields[kInit] = async_hook_fields[kInit];
-  active_hooks.tmp_fields[kBefore] = async_hook_fields[kBefore];
-  active_hooks.tmp_fields[kAfter] = async_hook_fields[kAfter];
-  active_hooks.tmp_fields[kDestroy] = async_hook_fields[kDestroy];
-  active_hooks.tmp_fields[kPromiseResolve] = async_hook_fields[kPromiseResolve];
+  copyHooks(active_hooks.tmp_fields, async_hook_fields);
+}
+
+function copyHooks(destination, source) {
+  destination[kInit] = source[kInit];
+  destination[kBefore] = source[kBefore];
+  destination[kAfter] = source[kAfter];
+  destination[kDestroy] = source[kDestroy];
+  destination[kPromiseResolve] = source[kPromiseResolve];
 }
 
 
@@ -219,11 +223,7 @@ function storeActiveHooks() {
 // during hook callback execution.
 function restoreActiveHooks() {
   active_hooks.array = active_hooks.tmp_array;
-  async_hook_fields[kInit] = active_hooks.tmp_fields[kInit];
-  async_hook_fields[kBefore] = active_hooks.tmp_fields[kBefore];
-  async_hook_fields[kAfter] = active_hooks.tmp_fields[kAfter];
-  async_hook_fields[kDestroy] = active_hooks.tmp_fields[kDestroy];
-  async_hook_fields[kPromiseResolve] = active_hooks.tmp_fields[kPromiseResolve];
+  copyHooks(async_hook_fields, active_hooks.tmp_fields);
 
   active_hooks.tmp_array = null;
   active_hooks.tmp_fields = null;
