@@ -14,6 +14,7 @@ const intercom = new EventEmitter();
 const SCHED_NONE = 1;
 const SCHED_RR = 2;
 const { isLegalPort } = require('internal/net');
+const [ minPort, maxPort ] = [ 1024, 65535 ];
 
 module.exports = cluster;
 
@@ -101,11 +102,14 @@ function createWorkerProcess(id, env) {
   const workerEnv = util._extend({}, process.env);
   const execArgv = cluster.settings.execArgv.slice();
   const debugArgRegex = /--inspect(?:-brk|-port)?|--debug-port/;
+  const nodeOptions = process.env.NODE_OPTIONS ?
+    process.env.NODE_OPTIONS : '';
 
   util._extend(workerEnv, env);
   workerEnv.NODE_UNIQUE_ID = '' + id;
 
-  if (execArgv.some((arg) => arg.match(debugArgRegex))) {
+  if (execArgv.some((arg) => arg.match(debugArgRegex)) ||
+      nodeOptions.match(debugArgRegex)) {
     let inspectPort;
     if ('inspectPort' in cluster.settings) {
       if (typeof cluster.settings.inspectPort === 'function')
@@ -119,6 +123,8 @@ function createWorkerProcess(id, env) {
       }
     } else {
       inspectPort = process.debugPort + debugPortOffset;
+      if (inspectPort > maxPort)
+        inspectPort = inspectPort - maxPort + minPort - 1;
       debugPortOffset++;
     }
 
