@@ -11,7 +11,7 @@ const { kMaxLength } = require('buffer');
 const kMaxUint32 = Math.pow(2, 32) - 1;
 
 function assertOffset(offset, length) {
-  if (typeof offset !== 'number' || offset !== offset) {
+  if (typeof offset !== 'number' || Number.isNaN(offset)) {
     throw new errors.TypeError('ERR_INVALID_ARG_TYPE', 'offset', 'number');
   }
 
@@ -25,7 +25,7 @@ function assertOffset(offset, length) {
 }
 
 function assertSize(size, offset = 0, length = Infinity) {
-  if (typeof size !== 'number' || size !== size) {
+  if (typeof size !== 'number' || Number.isNaN(size)) {
     throw new errors.TypeError('ERR_INVALID_ARG_TYPE', 'size', 'number');
   }
 
