@@ -122,32 +122,15 @@ function onStreamDrain() {
     response.emit('drain');
 }
 
-// TODO Http2Stream does not emit 'close'
-function onStreamClosedRequest() {
-  const request = this[kRequest];
-  if (request !== undefined)
-    request.push(null);
-}
-
-// TODO Http2Stream does not emit 'close'
-function onStreamClosedResponse() {
-  const response = this[kResponse];
-  if (response !== undefined)
-    response.emit('finish');
-}
-
 function onStreamAbortedRequest() {
   const request = this[kRequest];
   if (request !== undefined && request[kState].closed === false) {
     request.emit('aborted');
-    request.emit('close');
   }
 }
 
 function onStreamAbortedResponse() {
-  const response = this[kResponse];
-  if (response !== undefined && response[kState].closed === false)
-    response.emit('close');
+  // non-op for now
 }
 
 function resumeStream(stream) {
@@ -247,11 +230,8 @@ class Http2ServerRequest extends Readable {
     stream.on('trailers', onStreamTrailers);
     stream.on('end', onStreamEnd);
     stream.on('error', onStreamError);
-    stream.on('close', onStreamClosedRequest);
     stream.on('aborted', onStreamAbortedRequest);
-    const onfinish = this[kFinish].bind(this);
-    stream.on('streamClosed', onfinish);
-    stream.on('finish', onfinish);
+    stream.on('close', this[kFinish].bind(this));
     this.on('pause', onRequestPause);
     this.on('resume', onRequestResume);
   }
@@ -312,7 +292,7 @@ class Http2ServerRequest extends Readable {
       state.didRead = true;
       process.nextTick(resumeStream, this[kStream]);
     } else {
-      this.emit('error', new errors.Error('ERR_HTTP2_STREAM_CLOSED'));
+      this.emit('error', new errors.Error('ERR_HTTP2_INVALID_STREAM'));
     }
   }
 
@@ -360,6 +340,7 @@ class Http2ServerRequest extends Readable {
     // dump it for compatibility with http1
     if (!state.didRead && !this._readableState.resumeScheduled)
       this.resume();
+    this.emit('close');
   }
 }
 
@@ -380,11 +361,8 @@ class Http2ServerResponse extends Stream {
     stream[kResponse] = this;
     this.writable = true;
     stream.on('drain', onStreamDrain);
-    stream.on('close', onStreamClosedResponse);
     stream.on('aborted', onStreamAbortedResponse);
-    const onfinish = this[kFinish].bind(this);
-    stream.on('streamClosed', onfinish);
-    stream.on('finish', onfinish);
+    stream.on('close', this[kFinish].bind(this));
   }
 
   // User land modules such as finalhandler just check truthiness of this
@@ -536,7 +514,7 @@ class Http2ServerResponse extends Stream {
     const state = this[kState];
 
     if (state.closed)
-      throw new errors.Error('ERR_HTTP2_STREAM_CLOSED');
+      throw new errors.Error('ERR_HTTP2_INVALID_STREAM');
     if (this[kStream].headersSent)
       throw new errors.Error('ERR_HTTP2_HEADERS_SENT');
 
@@ -566,7 +544,7 @@ class Http2ServerResponse extends Stream {
     }
 
     if (this[kState].closed) {
-      const err = new errors.Error('ERR_HTTP2_STREAM_CLOSED');
+      const err = new errors.Error('ERR_HTTP2_INVALID_STREAM');
       if (typeof cb === 'function')
         process.nextTick(cb, err);
       else
@@ -636,12 +614,15 @@ class Http2ServerResponse extends Stream {
     if (typeof callback !== 'function')
       throw new errors.TypeError('ERR_INVALID_CALLBACK');
     if (this[kState].closed) {
-      process.nextTick(callback, new errors.Error('ERR_HTTP2_STREAM_CLOSED'));
+      process.nextTick(callback, new errors.Error('ERR_HTTP2_INVALID_STREAM'));
       return;
     }
-    this[kStream].pushStream(headers, {}, function(stream, headers, options) {
-      const response = new Http2ServerResponse(stream);
-      callback(null, response);
+    this[kStream].pushStream(headers, {}, (err, stream, headers, options) => {
+      if (err) {
+        callback(err);
+        return;
+      }
+      callback(null, new Http2ServerResponse(stream));
     });
   }
 
@@ -665,6 +646,7 @@ class Http2ServerResponse extends Stream {
     this[kProxySocket] = null;
     stream[kResponse] = undefined;
     this.emit('finish');
+    this.emit('close');
   }
 
   // TODO doesn't support callbacks
@@ -679,11 +661,11 @@ class Http2ServerResponse extends Stream {
   }
 }
 
-function onServerStream(stream, headers, flags, rawHeaders) {
+function onServerStream(ServerRequest, ServerResponse,
+                        stream, headers, flags, rawHeaders) {
   const server = this;
-  const request = new Http2ServerRequest(stream, headers, undefined,
-                                         rawHeaders);
-  const response = new Http2ServerResponse(stream);
+  const request = new ServerRequest(stream, headers, undefined, rawHeaders);
+  const response = new ServerResponse(stream);
 
   // Check for the CONNECT method
   const method = headers[HTTP2_HEADER_METHOD];
