@@ -174,7 +174,9 @@ const IDX_OPTIONS_PEER_MAX_CONCURRENT_STREAMS = 3;
 const IDX_OPTIONS_PADDING_STRATEGY = 4;
 const IDX_OPTIONS_MAX_HEADER_LIST_PAIRS = 5;
 const IDX_OPTIONS_MAX_OUTSTANDING_PINGS = 6;
-const IDX_OPTIONS_FLAGS = 7;
+const IDX_OPTIONS_MAX_OUTSTANDING_SETTINGS = 7;
+const IDX_OPTIONS_MAX_SESSION_MEMORY = 8;
+const IDX_OPTIONS_FLAGS = 9;
 
 function updateOptionsBuffer(options) {
   var flags = 0;
@@ -213,6 +215,16 @@ function updateOptionsBuffer(options) {
     optionsBuffer[IDX_OPTIONS_MAX_OUTSTANDING_PINGS] =
       options.maxOutstandingPings;
   }
+  if (typeof options.maxOutstandingSettings === 'number') {
+    flags |= (1 << IDX_OPTIONS_MAX_OUTSTANDING_SETTINGS);
+    optionsBuffer[IDX_OPTIONS_MAX_OUTSTANDING_SETTINGS] =
+      Math.max(1, options.maxOutstandingSettings);
+  }
+  if (typeof options.maxSessionMemory === 'number') {
+    flags |= (1 << IDX_OPTIONS_MAX_SESSION_MEMORY);
+    optionsBuffer[IDX_OPTIONS_MAX_SESSION_MEMORY] =
+      Math.max(1, options.maxSessionMemory);
+  }
   optionsBuffer[IDX_OPTIONS_FLAGS] = flags;
 }
 
