@@ -44,13 +44,17 @@ function isPathSeparator(code) {
   return code === CHAR_FORWARD_SLASH || code === CHAR_BACKWARD_SLASH;
 }
 
+function isPosixPathSeparator(code) {
+  return code === CHAR_FORWARD_SLASH;
+}
+
 function isWindowsDeviceRoot(code) {
   return code >= CHAR_UPPERCASE_A && code <= CHAR_UPPERCASE_Z ||
          code >= CHAR_LOWERCASE_A && code <= CHAR_LOWERCASE_Z;
 }
 
 // Resolves . and .. elements in a path with directory names
-function normalizeString(path, allowAboveRoot, separator) {
+function normalizeString(path, allowAboveRoot, separator, isPathSeparator) {
   var res = '';
   var lastSegmentLength = 0;
   var lastSlash = -1;
@@ -272,7 +276,8 @@ const win32 = {
     // fails)
 
     // Normalize the tail path
-    resolvedTail = normalizeString(resolvedTail, !resolvedAbsolute, '\\');
+    resolvedTail = normalizeString(resolvedTail, !resolvedAbsolute, '\\',
+                                   isPathSeparator);
 
     return (resolvedDevice + (resolvedAbsolute ? '\\' : '') + resolvedTail) ||
            '.';
@@ -363,10 +368,12 @@ const win32 = {
     }
 
     var tail;
-    if (rootEnd < len)
-      tail = normalizeString(path.slice(rootEnd), !isAbsolute, '\\');
-    else
+    if (rootEnd < len) {
+      tail = normalizeString(path.slice(rootEnd), !isAbsolute, '\\',
+                             isPathSeparator);
+    } else {
       tail = '';
+    }
     if (tail.length === 0 && !isAbsolute)
       tail = '.';
     if (tail.length > 0 && isPathSeparator(path.charCodeAt(len - 1)))
@@ -1096,7 +1103,8 @@ const posix = {
     // handle relative paths to be safe (might happen when process.cwd() fails)
 
     // Normalize the path
-    resolvedPath = normalizeString(resolvedPath, !resolvedAbsolute, '/');
+    resolvedPath = normalizeString(resolvedPath, !resolvedAbsolute, '/',
+                                   isPosixPathSeparator);
 
     if (resolvedAbsolute) {
       if (resolvedPath.length > 0)
@@ -1122,7 +1130,7 @@ const posix = {
       path.charCodeAt(path.length - 1) === CHAR_FORWARD_SLASH;
 
     // Normalize the path
-    path = normalizeString(path, !isAbsolute, '/');
+    path = normalizeString(path, !isAbsolute, '/', isPosixPathSeparator);
 
     if (path.length === 0 && !isAbsolute)
       path = '.';
