@@ -1,6 +1,34 @@
+// Copyright Joyent, Inc. and other Node contributors.
+//
+// Permission is hereby granted, free of charge, to any person obtaining a
+// copy of this software and associated documentation files (the
+// "Software"), to deal in the Software without restriction, including
+// without limitation the rights to use, copy, modify, merge, publish,
+// distribute, sublicense, and/or sell copies of the Software, and to permit
+// persons to whom the Software is furnished to do so, subject to the
+// following conditions:
+//
+// The above copyright notice and this permission notice shall be included
+// in all copies or substantial portions of the Software.
+//
+// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
+// OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
+// MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN
+// NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM,
+// DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR
+// OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE
+// USE OR OTHER DEALINGS IN THE SOFTWARE.
+
+// Query String Utilities
+
 'use strict';
 
-const { hexTable } = require('internal/querystring');
+const { Buffer } = require('buffer');
+const errors = require('internal/errors');
+const {
+  hexTable,
+  isHexTable
+} = require('internal/querystring');
 const QueryString = module.exports = {
   unescapeBuffer,
   // `unescape()` is a JS global, so we need to use a different local name
@@ -15,13 +43,6 @@ const QueryString = module.exports = {
   parse,
   decode: parse
 };
-const Buffer = require('buffer').Buffer;
-
-// This constructor is used to store parsed query string values. Instantiating
-// this is faster than explicitly calling `Object.create(null)` to get a
-// "clean" empty object (tested with v8 v4.9).
-function ParsedQueryString() {}
-ParsedQueryString.prototype = Object.create(null);
 
 const unhexTable = [
   -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, // 0 - 15
@@ -44,67 +65,44 @@ const unhexTable = [
 // a safe fast alternative to decodeURIComponent
 function unescapeBuffer(s, decodeSpaces) {
   var out = Buffer.allocUnsafe(s.length);
-  var state = 0;
-  var n, m, hexchar, c;
-
-  for (var inIndex = 0, outIndex = 0; ; inIndex++) {
-    if (inIndex < s.length) {
-      c = s.charCodeAt(inIndex);
-    } else {
-      if (state > 0) {
-        out[outIndex++] = 37/*%*/;
-        if (state === 2)
-          out[outIndex++] = hexchar;
+  var index = 0;
+  var outIndex = 0;
+  var currentChar;
+  var nextChar;
+  var hexHigh;
+  var hexLow;
+  var maxLength = s.length - 2;
+  // Flag to know if some hex chars have been decoded
+  var hasHex = false;
+  while (index < s.length) {
+    currentChar = s.charCodeAt(index);
+    if (currentChar === 43 /*'+'*/ && decodeSpaces) {
+      out[outIndex++] = 32; // ' '
+      index++;
+      continue;
+    }
+    if (currentChar === 37 /*'%'*/ && index < maxLength) {
+      currentChar = s.charCodeAt(++index);
+      hexHigh = unhexTable[currentChar];
+      if (!(hexHigh >= 0)) {
+        out[outIndex++] = 37; // '%'
+      } else {
+        nextChar = s.charCodeAt(++index);
+        hexLow = unhexTable[nextChar];
+        if (!(hexLow >= 0)) {
+          out[outIndex++] = 37; // '%'
+          out[outIndex++] = currentChar;
+          currentChar = nextChar;
+        } else {
+          hasHex = true;
+          currentChar = hexHigh * 16 + hexLow;
+        }
       }
-      break;
-    }
-    switch (state) {
-      case 0: // Any character
-        switch (c) {
-          case 37: // '%'
-            n = 0;
-            m = 0;
-            state = 1;
-            break;
-          case 43: // '+'
-            if (decodeSpaces)
-              c = 32; // ' '
-            // falls through
-          default:
-            out[outIndex++] = c;
-            break;
-        }
-        break;
-
-      case 1: // First hex digit
-        hexchar = c;
-        n = unhexTable[c];
-        if (!(n >= 0)) {
-          out[outIndex++] = 37/*%*/;
-          out[outIndex++] = c;
-          state = 0;
-          break;
-        }
-        state = 2;
-        break;
-
-      case 2: // Second hex digit
-        state = 0;
-        m = unhexTable[c];
-        if (!(m >= 0)) {
-          out[outIndex++] = 37/*%*/;
-          out[outIndex++] = hexchar;
-          out[outIndex++] = c;
-          break;
-        }
-        out[outIndex++] = 16 * n + m;
-        break;
     }
+    out[outIndex++] = currentChar;
+    index++;
   }
-
-  // TODO support returning arbitrary buffers.
-
-  return out.slice(0, outIndex);
+  return hasHex ? out.slice(0, outIndex) : out;
 }
 
 
@@ -177,11 +175,12 @@ function qsEscape(str) {
     }
     // Surrogate pair
     ++i;
-    var c2;
-    if (i < str.length)
-      c2 = str.charCodeAt(i) & 0x3FF;
-    else
-      throw new URIError('URI malformed');
+
+    if (i >= str.length)
+      throw new errors.URIError('ERR_INVALID_URI');
+
+    var c2 = str.charCodeAt(i) & 0x3FF;
+
     lastPos = i + 1;
     c = 0x10000 + (((c & 0x3FF) << 10) | c2);
     out += hexTable[0xF0 | (c >> 18)] +
@@ -260,7 +259,7 @@ const defEqCodes = [61]; // =
 
 // Parse a key/val string.
 function parse(qs, sep, eq, options) {
-  const obj = new ParsedQueryString();
+  const obj = Object.create(null);
 
   if (typeof qs !== 'string' || qs.length === 0) {
     return obj;
@@ -288,7 +287,6 @@ function parse(qs, sep, eq, options) {
   }
   const customDecode = (decode !== qsUnescape);
 
-  const keys = [];
   var lastPos = 0;
   var sepIdx = 0;
   var eqIdx = 0;
@@ -296,6 +294,7 @@ function parse(qs, sep, eq, options) {
   var value = '';
   var keyEncoded = customDecode;
   var valEncoded = customDecode;
+  const plusChar = (customDecode ? '%20' : ' ');
   var encodeCheck = 0;
   for (var i = 0; i < qs.length; ++i) {
     const code = qs.charCodeAt(i);
@@ -306,134 +305,137 @@ function parse(qs, sep, eq, options) {
         // Key/value pair separator match!
         const end = i - sepIdx + 1;
         if (eqIdx < eqLen) {
-          // If we didn't find the key/value separator, treat the substring as
-          // part of the key instead of the value
-          if (lastPos < end)
+          // We didn't find the (entire) key/value separator
+          if (lastPos < end) {
+            // Treat the substring as part of the key instead of the value
             key += qs.slice(lastPos, end);
-        } else if (lastPos < end)
+          } else if (key.length === 0) {
+            // We saw an empty substring between separators
+            if (--pairs === 0)
+              return obj;
+            lastPos = i + 1;
+            sepIdx = eqIdx = 0;
+            continue;
+          }
+        } else if (lastPos < end) {
           value += qs.slice(lastPos, end);
-        if (keyEncoded)
+        }
+
+        if (key.length > 0 && keyEncoded)
           key = decodeStr(key, decode);
-        if (valEncoded)
+        if (value.length > 0 && valEncoded)
           value = decodeStr(value, decode);
-        // Use a key array lookup instead of using hasOwnProperty(), which is
-        // slower
-        if (keys.indexOf(key) === -1) {
+
+        if (obj[key] === undefined) {
           obj[key] = value;
-          keys[keys.length] = key;
         } else {
           const curValue = obj[key];
           // A simple Array-specific property check is enough here to
-          // distinguish from a string value and is faster and still safe since
-          // we are generating all of the values being assigned.
+          // distinguish from a string value and is faster and still safe
+          // since we are generating all of the values being assigned.
           if (curValue.pop)
             curValue[curValue.length] = value;
           else
             obj[key] = [curValue, value];
         }
         if (--pairs === 0)
-          break;
+          return obj;
         keyEncoded = valEncoded = customDecode;
-        encodeCheck = 0;
         key = value = '';
+        encodeCheck = 0;
         lastPos = i + 1;
         sepIdx = eqIdx = 0;
       }
-      continue;
     } else {
       sepIdx = 0;
-      if (!valEncoded) {
+      // Try matching key/value separator (e.g. '=') if we haven't already
+      if (eqIdx < eqLen) {
+        if (code === eqCodes[eqIdx]) {
+          if (++eqIdx === eqLen) {
+            // Key/value separator match!
+            const end = i - eqIdx + 1;
+            if (lastPos < end)
+              key += qs.slice(lastPos, end);
+            encodeCheck = 0;
+            lastPos = i + 1;
+          }
+          continue;
+        } else {
+          eqIdx = 0;
+          if (!keyEncoded) {
+            // Try to match an (valid) encoded byte once to minimize unnecessary
+            // calls to string decoding functions
+            if (code === 37/*%*/) {
+              encodeCheck = 1;
+              continue;
+            } else if (encodeCheck > 0) {
+              // eslint-disable-next-line no-extra-boolean-cast
+              if (!!isHexTable[code]) {
+                if (++encodeCheck === 3)
+                  keyEncoded = true;
+                continue;
+              } else {
+                encodeCheck = 0;
+              }
+            }
+          }
+        }
+        if (code === 43/*+*/) {
+          if (lastPos < i)
+            key += qs.slice(lastPos, i);
+          key += plusChar;
+          lastPos = i + 1;
+          continue;
+        }
+      }
+      if (code === 43/*+*/) {
+        if (lastPos < i)
+          value += qs.slice(lastPos, i);
+        value += plusChar;
+        lastPos = i + 1;
+      } else if (!valEncoded) {
         // Try to match an (valid) encoded byte (once) to minimize unnecessary
         // calls to string decoding functions
         if (code === 37/*%*/) {
           encodeCheck = 1;
-        } else if (encodeCheck > 0 &&
-                   ((code >= 48/*0*/ && code <= 57/*9*/) ||
-                    (code >= 65/*A*/ && code <= 70/*F*/) ||
-                    (code >= 97/*a*/ && code <= 102/*f*/))) {
-          if (++encodeCheck === 3)
-            valEncoded = true;
-        } else {
-          encodeCheck = 0;
-        }
-      }
-    }
-
-    // Try matching key/value separator (e.g. '=') if we haven't already
-    if (eqIdx < eqLen) {
-      if (code === eqCodes[eqIdx]) {
-        if (++eqIdx === eqLen) {
-          // Key/value separator match!
-          const end = i - eqIdx + 1;
-          if (lastPos < end)
-            key += qs.slice(lastPos, end);
-          encodeCheck = 0;
-          lastPos = i + 1;
-        }
-        continue;
-      } else {
-        eqIdx = 0;
-        if (!keyEncoded) {
-          // Try to match an (valid) encoded byte once to minimize unnecessary
-          // calls to string decoding functions
-          if (code === 37/*%*/) {
-            encodeCheck = 1;
-          } else if (encodeCheck > 0 &&
-                     ((code >= 48/*0*/ && code <= 57/*9*/) ||
-                      (code >= 65/*A*/ && code <= 70/*F*/) ||
-                      (code >= 97/*a*/ && code <= 102/*f*/))) {
+        } else if (encodeCheck > 0) {
+          // eslint-disable-next-line no-extra-boolean-cast
+          if (!!isHexTable[code]) {
             if (++encodeCheck === 3)
-              keyEncoded = true;
+              valEncoded = true;
           } else {
             encodeCheck = 0;
           }
         }
       }
     }
-
-    if (code === 43/*+*/) {
-      if (eqIdx < eqLen) {
-        if (lastPos < i)
-          key += qs.slice(lastPos, i);
-        key += '%20';
-        keyEncoded = true;
-      } else {
-        if (lastPos < i)
-          value += qs.slice(lastPos, i);
-        value += '%20';
-        valEncoded = true;
-      }
-      lastPos = i + 1;
-    }
   }
 
-  // Check if we have leftover key or value data
-  if (pairs !== 0 && (lastPos < qs.length || eqIdx > 0)) {
-    if (lastPos < qs.length) {
-      if (eqIdx < eqLen)
-        key += qs.slice(lastPos);
-      else if (sepIdx < sepLen)
-        value += qs.slice(lastPos);
-    }
-    if (keyEncoded)
-      key = decodeStr(key, decode);
-    if (valEncoded)
-      value = decodeStr(value, decode);
-    // Use a key array lookup instead of using hasOwnProperty(), which is
-    // slower
-    if (keys.indexOf(key) === -1) {
-      obj[key] = value;
-      keys[keys.length] = key;
-    } else {
-      const curValue = obj[key];
-      // A simple Array-specific property check is enough here to
-      // distinguish from a string value and is faster and still safe since
-      // we are generating all of the values being assigned.
-      if (curValue.pop)
-        curValue[curValue.length] = value;
-      else
-        obj[key] = [curValue, value];
-    }
+  // Deal with any leftover key or value data
+  if (lastPos < qs.length) {
+    if (eqIdx < eqLen)
+      key += qs.slice(lastPos);
+    else if (sepIdx < sepLen)
+      value += qs.slice(lastPos);
+  } else if (eqIdx === 0 && key.length === 0) {
+    // We ended on an empty substring
+    return obj;
+  }
+  if (key.length > 0 && keyEncoded)
+    key = decodeStr(key, decode);
+  if (value.length > 0 && valEncoded)
+    value = decodeStr(value, decode);
+  if (obj[key] === undefined) {
+    obj[key] = value;
+  } else {
+    const curValue = obj[key];
+    // A simple Array-specific property check is enough here to
+    // distinguish from a string value and is faster and still safe since
+    // we are generating all of the values being assigned.
+    if (curValue.pop)
+      curValue[curValue.length] = value;
+    else
+      obj[key] = [curValue, value];
   }
 
   return obj;
