@@ -21,19 +21,23 @@
 
 'use strict';
 
-const util = require('util');
+const { inherits, _extend } = require('util');
 const net = require('net');
-const TTY = process.binding('tty_wrap').TTY;
-const isTTY = process.binding('tty_wrap').isTTY;
-const inherits = util.inherits;
-const errnoException = util._errnoException;
+const { TTY, isTTY } = process.binding('tty_wrap');
 const errors = require('internal/errors');
 const readline = require('readline');
+const { release } = require('os');
 
-exports.isatty = function(fd) {
+const OSRelease = release().split('.');
+
+const COLORS_2 = 1;
+const COLORS_16 = 4;
+const COLORS_256 = 8;
+const COLORS_16m = 24;
+
+function isatty(fd) {
   return Number.isInteger(fd) && fd >= 0 && isTTY(fd);
-};
-
+}
 
 function ReadStream(fd, options) {
   if (!(this instanceof ReadStream))
@@ -41,7 +45,7 @@ function ReadStream(fd, options) {
   if (fd >> 0 !== fd || fd < 0)
     throw new errors.RangeError('ERR_INVALID_FD', fd);
 
-  options = util._extend({
+  options = _extend({
     highWaterMark: 0,
     readable: true,
     writable: false,
@@ -55,15 +59,12 @@ function ReadStream(fd, options) {
 }
 inherits(ReadStream, net.Socket);
 
-exports.ReadStream = ReadStream;
-
 ReadStream.prototype.setRawMode = function(flag) {
   flag = !!flag;
   this._handle.setRawMode(flag);
   this.isRaw = flag;
 };
 
-
 function WriteStream(fd) {
   if (!(this instanceof WriteStream))
     return new WriteStream(fd);
@@ -83,31 +84,92 @@ function WriteStream(fd) {
   // Ref: https://github.com/nodejs/node/pull/1771#issuecomment-119351671
   this._handle.setBlocking(true);
 
-  var winSize = new Array(2);
-  var err = this._handle.getWindowSize(winSize);
+  const winSize = new Array(2);
+  const err = this._handle.getWindowSize(winSize);
   if (!err) {
     this.columns = winSize[0];
     this.rows = winSize[1];
   }
 }
 inherits(WriteStream, net.Socket);
-exports.WriteStream = WriteStream;
-
 
 WriteStream.prototype.isTTY = true;
 
+WriteStream.prototype.getColorDepth = function(env = process.env) {
+  if (env.NODE_DISABLE_COLORS || env.TERM === 'dumb' && !env.COLORTERM) {
+    return COLORS_2;
+  }
+
+  if (process.platform === 'win32') {
+    // Windows 10 build 10586 is the first Windows release that supports 256
+    // colors. Windows 10 build 14931 is the first release that supports
+    // 16m/TrueColor.
+    if (+OSRelease[0] >= 10) {
+      const build = +OSRelease[2];
+      if (build >= 14931)
+        return COLORS_16m;
+      if (build >= 10586)
+        return COLORS_256;
+    }
+
+    return COLORS_16;
+  }
+
+  if (env.TMUX) {
+    return COLORS_256;
+  }
+
+  if (env.CI) {
+    if ('TRAVIS' in env || 'CIRCLECI' in env || 'APPVEYOR' in env ||
+      'GITLAB_CI' in env || env.CI_NAME === 'codeship') {
+      return COLORS_256;
+    }
+    return COLORS_2;
+  }
+
+  if ('TEAMCITY_VERSION' in env) {
+    return /^(9\.(0*[1-9]\d*)\.|\d{2,}\.)/.test(env.TEAMCITY_VERSION) ?
+      COLORS_16 : COLORS_2;
+  }
+
+  switch (env.TERM_PROGRAM) {
+    case 'iTerm.app':
+      if (!env.TERM_PROGRAM_VERSION ||
+        /^[0-2]\./.test(env.TERM_PROGRAM_VERSION)) {
+        return COLORS_256;
+      }
+      return COLORS_16m;
+    case 'HyperTerm':
+    case 'Hyper':
+    case 'MacTerm':
+      return COLORS_16m;
+    case 'Apple_Terminal':
+      return COLORS_256;
+  }
+
+  if (env.TERM) {
+    if (/^xterm-256/.test(env.TERM))
+      return COLORS_256;
+    if (/^screen|^xterm|^vt100|color|ansi|cygwin|linux/i.test(env.TERM))
+      return COLORS_16;
+  }
+
+  if (env.COLORTERM)
+    return COLORS_16;
+
+  return COLORS_2;
+};
 
 WriteStream.prototype._refreshSize = function() {
-  var oldCols = this.columns;
-  var oldRows = this.rows;
-  var winSize = new Array(2);
-  var err = this._handle.getWindowSize(winSize);
+  const oldCols = this.columns;
+  const oldRows = this.rows;
+  const winSize = new Array(2);
+  const err = this._handle.getWindowSize(winSize);
   if (err) {
-    this.emit('error', errnoException(err, 'getWindowSize'));
+    this.emit('error', errors.errnoException(err, 'getWindowSize'));
     return;
   }
-  var newCols = winSize[0];
-  var newRows = winSize[1];
+  const [newCols, newRows] = winSize;
   if (oldCols !== newCols || oldRows !== newRows) {
     this.columns = newCols;
     this.rows = newRows;
@@ -115,8 +177,7 @@ WriteStream.prototype._refreshSize = function() {
   }
 };
 
-
-// backwards-compat
+// Backwards-compat
 WriteStream.prototype.cursorTo = function(x, y) {
   readline.cursorTo(this, x, y);
 };
@@ -132,3 +193,5 @@ WriteStream.prototype.clearScreenDown = function() {
 WriteStream.prototype.getWindowSize = function() {
   return [this.columns, this.rows];
 };
+
+module.exports = { isatty, ReadStream, WriteStream };
