@@ -177,7 +177,7 @@ function Zlib(opts, mode) {
 
   if (opts) {
     chunkSize = opts.chunkSize;
-    if (chunkSize !== undefined && chunkSize === chunkSize) {
+    if (chunkSize !== undefined && !Number.isNaN(chunkSize)) {
       if (chunkSize < Z_MIN_CHUNK || !Number.isFinite(chunkSize))
         throw new errors.RangeError('ERR_INVALID_OPT_VALUE',
                                     'chunkSize',
@@ -187,7 +187,7 @@ function Zlib(opts, mode) {
     }
 
     flush = opts.flush;
-    if (flush !== undefined && flush === flush) {
+    if (flush !== undefined && !Number.isNaN(flush)) {
       if (flush < Z_NO_FLUSH || flush > Z_BLOCK || !Number.isFinite(flush))
         throw new errors.RangeError('ERR_INVALID_OPT_VALUE', 'flush', flush);
     } else {
@@ -195,7 +195,7 @@ function Zlib(opts, mode) {
     }
 
     finishFlush = opts.finishFlush;
-    if (finishFlush !== undefined && finishFlush === finishFlush) {
+    if (finishFlush !== undefined && !Number.isNaN(finishFlush)) {
       if (finishFlush < Z_NO_FLUSH || finishFlush > Z_BLOCK ||
           !Number.isFinite(finishFlush)) {
         throw new errors.RangeError('ERR_INVALID_OPT_VALUE',
@@ -207,7 +207,7 @@ function Zlib(opts, mode) {
     }
 
     windowBits = opts.windowBits;
-    if (windowBits !== undefined && windowBits === windowBits) {
+    if (windowBits !== undefined && !Number.isNaN(windowBits)) {
       if (windowBits < Z_MIN_WINDOWBITS || windowBits > Z_MAX_WINDOWBITS ||
           !Number.isFinite(windowBits)) {
         throw new errors.RangeError('ERR_INVALID_OPT_VALUE',
@@ -219,7 +219,7 @@ function Zlib(opts, mode) {
     }
 
     level = opts.level;
-    if (level !== undefined && level === level) {
+    if (level !== undefined && !Number.isNaN(level)) {
       if (level < Z_MIN_LEVEL || level > Z_MAX_LEVEL ||
           !Number.isFinite(level)) {
         throw new errors.RangeError('ERR_INVALID_OPT_VALUE',
@@ -230,7 +230,7 @@ function Zlib(opts, mode) {
     }
 
     memLevel = opts.memLevel;
-    if (memLevel !== undefined && memLevel === memLevel) {
+    if (memLevel !== undefined && !Number.isNaN(memLevel)) {
       if (memLevel < Z_MIN_MEMLEVEL || memLevel > Z_MAX_MEMLEVEL ||
           !Number.isFinite(memLevel)) {
         throw new errors.RangeError('ERR_INVALID_OPT_VALUE',
@@ -241,7 +241,7 @@ function Zlib(opts, mode) {
     }
 
     strategy = opts.strategy;
-    if (strategy !== undefined && strategy === strategy) {
+    if (strategy !== undefined && !Number.isNaN(strategy)) {
       if (strategy < Z_DEFAULT_STRATEGY || strategy > Z_FIXED ||
           !Number.isFinite(strategy)) {
         throw new errors.TypeError('ERR_INVALID_OPT_VALUE',
@@ -374,7 +374,7 @@ Zlib.prototype.flush = function flush(kind, callback) {
     this._scheduledFlushFlag = maxFlush(kind, this._scheduledFlushFlag);
 
     // If a callback was passed, always register a new `drain` + flush handler,
-    // mostly because that’s simpler and flush callbacks piling up is a rare
+    // mostly because that's simpler and flush callbacks piling up is a rare
     // thing anyway.
     if (!alreadyHadFlushScheduled || callback) {
       const drainHandler = () => this.flush(this._scheduledFlushFlag, callback);
