@@ -218,25 +218,25 @@ void Environment::PrintSyncTrace() const {
 }
 
 void Environment::RunBeforeExitCallbacks() {
-  for (BeforeExitCallback before_exit : before_exit_functions_) {
+  for (ExitCallback before_exit : before_exit_functions_) {
     before_exit.cb_(before_exit.arg_);
   }
   before_exit_functions_.clear();
 }
 
 void Environment::BeforeExit(void (*cb)(void* arg), void* arg) {
-  before_exit_functions_.push_back(BeforeExitCallback{cb, arg});
+  before_exit_functions_.push_back(ExitCallback{cb, arg});
 }
 
 void Environment::RunAtExitCallbacks() {
-  for (AtExitCallback at_exit : at_exit_functions_) {
+  for (ExitCallback at_exit : at_exit_functions_) {
     at_exit.cb_(at_exit.arg_);
   }
   at_exit_functions_.clear();
 }
 
 void Environment::AtExit(void (*cb)(void* arg), void* arg) {
-  at_exit_functions_.push_back(AtExitCallback{cb, arg});
+  at_exit_functions_.push_back(ExitCallback{cb, arg});
 }
 
 void Environment::AddPromiseHook(promise_hook_func fn, void* arg) {
