@@ -2,11 +2,10 @@
 'use strict';
 
 const common = require('../common');
-const Buffer = require('buffer').Buffer;
 
 const bufferWarning = 'The Buffer() and new Buffer() constructors are not ' +
                       'recommended for use due to security and usability ' +
-                      'concerns. Please use the new Buffer.alloc(), ' +
+                      'concerns. Please use the Buffer.alloc(), ' +
                       'Buffer.allocUnsafe(), or Buffer.from() construction ' +
                       'methods instead.';
 
