@@ -15,11 +15,7 @@ function read(buff, funx, args, expected) {
     }
   );
 
-  assert.doesNotThrow(
-    () => assert.strictEqual(buff[funx](...args, true), expected),
-    'noAssert does not change return value for valid ranges'
-  );
-
+  assert.strictEqual(buff[funx](...args, true), expected);
 }
 
 // testing basic functionality of readDoubleBE() and readDoubleLE()
