@@ -6,7 +6,7 @@ if (!common.hasCrypto)
 
 const http2 = require('http2');
 
-const invalidOptions = [() => {}, 1, 'test', null, undefined];
+const invalidOptions = [() => {}, 1, 'test', null];
 const invalidArgTypeError = {
   type: TypeError,
   code: 'ERR_INVALID_ARG_TYPE',
@@ -14,9 +14,9 @@ const invalidArgTypeError = {
 };
 
 // Error if options are not passed to createSecureServer
-invalidOptions.forEach((invalidOption) =>
+invalidOptions.forEach((invalidOption) => {
   common.expectsError(
     () => http2.createSecureServer(invalidOption),
     invalidArgTypeError
-  )
-);
+  );
+});
