@@ -1,4 +1,3 @@
-//
 'use strict';
 
 const common = require('../common');
@@ -7,11 +6,6 @@ if (!common.hasCrypto)
 const fixtures = require('../common/fixtures');
 const http2 = require('http2');
 
-const {
-  HTTP2_HEADER_CONTENT_TYPE,
-  HTTP2_HEADER_METHOD
-} = http2.constants;
-
 const optionsWithTypeError = {
   offset: 'number',
   length: 'number',
@@ -34,6 +28,7 @@ const fname = fixtures.path('elipses.txt');
 const server = http2.createServer();
 
 server.on('stream', common.mustCall((stream) => {
+
   // Check for all possible TypeError triggers on options
   Object.keys(optionsWithTypeError).forEach((option) => {
     Object.keys(types).forEach((type) => {
@@ -43,7 +38,7 @@ server.on('stream', common.mustCall((stream) => {
 
       common.expectsError(
         () => stream.respondWithFile(fname, {
-          [http2.constants.HTTP2_HEADER_CONTENT_TYPE]: 'text/plain'
+          'content-type': 'text/plain'
         }, {
           [option]: types[type]
         }),
@@ -60,7 +55,7 @@ server.on('stream', common.mustCall((stream) => {
   // Should throw if :status 204, 205 or 304
   [204, 205, 304].forEach((status) => common.expectsError(
     () => stream.respondWithFile(fname, {
-      [HTTP2_HEADER_CONTENT_TYPE]: 'text/plain',
+      'content-type': 'text/plain',
       ':status': status,
     }),
     {
@@ -69,31 +64,11 @@ server.on('stream', common.mustCall((stream) => {
     }
   ));
 
-  // should emit an error on the stream if headers aren't valid
-  stream.respondWithFile(fname, {
-    [HTTP2_HEADER_METHOD]: 'POST'
-  }, {
-    statCheck: common.mustCall(() => {
-      // give time to the current test case to finish
-      process.nextTick(continueTest, stream);
-      return true;
-    })
-  });
-  stream.once('error', common.expectsError({
-    code: 'ERR_HTTP2_INVALID_PSEUDOHEADER',
-    type: Error,
-    message: '":method" is an invalid pseudoheader or is used incorrectly'
-  }));
-}));
-
-function continueTest(stream) {
   // Should throw if headers already sent
-  stream.respond({
-    ':status': 200,
-  });
+  stream.respond({ ':status': 200 });
   common.expectsError(
     () => stream.respondWithFile(fname, {
-      [HTTP2_HEADER_CONTENT_TYPE]: 'text/plain'
+      'content-type': 'text/plain'
     }),
     {
       code: 'ERR_HTTP2_HEADERS_SENT',
@@ -105,21 +80,21 @@ function continueTest(stream) {
   stream.destroy();
   common.expectsError(
     () => stream.respondWithFile(fname, {
-      [HTTP2_HEADER_CONTENT_TYPE]: 'text/plain'
+      'content-type': 'text/plain'
     }),
     {
       code: 'ERR_HTTP2_INVALID_STREAM',
       message: 'The stream has been destroyed'
     }
   );
-}
+}));
 
 server.listen(0, common.mustCall(() => {
   const client = http2.connect(`http://localhost:${server.address().port}`);
   const req = client.request();
 
-  req.on('streamClosed', common.mustCall(() => {
-    client.destroy();
+  req.on('close', common.mustCall(() => {
+    client.close();
     server.close();
   }));
   req.end();
