@@ -1,4 +1,3 @@
-//
 'use strict';
 
 const common = require('../common');
@@ -21,7 +20,7 @@ server.listen(0, common.mustCall(() => {
   const req = client.request(headers);
   req.setEncoding('utf8');
   req.on('response', common.mustCall(function(headers) {
-    assert.strictEqual(headers['foobar'], 'baz');
+    assert.strictEqual(headers.foobar, 'baz');
     assert.strictEqual(headers['x-powered-by'], 'node-test');
   }));
 
@@ -30,7 +29,7 @@ server.listen(0, common.mustCall(() => {
   req.on('end', () => {
     assert.strictEqual(body, data);
     server.close();
-    client.destroy();
+    client.close();
   });
   req.end();
 }));
