@@ -1,17 +1,13 @@
-//
+// Flags: --expose-internals
+
 'use strict';
 
 const common = require('../common');
 if (!common.hasCrypto)
   common.skip('missing crypto');
-const h2 = require('http2');
 const assert = require('assert');
-
-const {
-  HTTP2_HEADER_METHOD,
-  HTTP2_HEADER_PATH,
-  HTTP2_METHOD_POST
-} = h2.constants;
+const h2 = require('http2');
+const { kSocket } = require('internal/http2/util');
 
 const server = h2.createServer();
 
@@ -19,17 +15,15 @@ const server = h2.createServer();
 server.on('stream', common.mustCall(onStream));
 
 function onStream(stream) {
-  stream.respond({
-    'content-type': 'text/html',
-    ':status': 200
-  });
+  stream.respond();
   stream.write('test');
 
-  const socket = stream.session.socket;
+  const socket = stream.session[kSocket];
 
   // When the socket is destroyed, the close events must be triggered
   // on the socket, server and session.
   socket.on('close', common.mustCall());
+  stream.on('close', common.mustCall());
   server.on('close', common.mustCall());
   stream.session.on('close', common.mustCall(() => server.close()));
 
@@ -38,23 +32,25 @@ function onStream(stream) {
 
   assert.notStrictEqual(stream.session, undefined);
   socket.destroy();
-  stream.on('destroy', common.mustCall(() => {
-    assert.strictEqual(stream.session, undefined);
-  }));
 }
 
 server.listen(0);
 
 server.on('listening', common.mustCall(() => {
   const client = h2.connect(`http://localhost:${server.address().port}`);
+  // The client may have an ECONNRESET error here depending on the operating
+  // system, due mainly to differences in the timing of socket closing. Do
+  // not wrap this in a common mustCall.
+  client.on('error', () => {});
+  client.on('close', common.mustCall());
 
-  const req = client.request({
-    [HTTP2_HEADER_PATH]: '/',
-    [HTTP2_HEADER_METHOD]: HTTP2_METHOD_POST });
+  const req = client.request({ ':method': 'POST' });
+  // The client may have an ECONNRESET error here depending on the operating
+  // system, due mainly to differences in the timing of socket closing. Do
+  // not wrap this in a common mustCall.
+  req.on('error', () => {});
 
   req.on('aborted', common.mustCall());
   req.resume();
   req.on('end', common.mustCall());
-
-  client.on('close', common.mustCall());
 }));
