@@ -16,12 +16,13 @@ const url = require('url');
   [() => {}, 'function'],
   [Symbol('foo'), 'symbol']
 ].forEach(([val, type]) => {
-  const error = common.expectsError({
+  common.expectsError(() => {
+    url.parse(val);
+  }, {
     code: 'ERR_INVALID_ARG_TYPE',
     type: TypeError,
     message: `The "url" argument must be of type string. Received type ${type}`
   });
-  assert.throws(() => { url.parse(val); }, error);
 });
 
 assert.throws(() => { url.parse('http://%E0%A4%A@fail'); },
