@@ -37,20 +37,20 @@ test(function() {
 // Tests below are not from WPT.
 {
   const params = new URLSearchParams();
-  assert.throws(() => {
+  common.expectsError(() => {
     params.get.call(undefined);
-  }, common.expectsError({
+  }, {
     code: 'ERR_INVALID_THIS',
     type: TypeError,
     message: 'Value of "this" must be of type URLSearchParams'
-  }));
-  assert.throws(() => {
+  });
+  common.expectsError(() => {
     params.get();
-  }, common.expectsError({
+  }, {
     code: 'ERR_MISSING_ARGS',
     type: TypeError,
     message: 'The "name" argument must be specified'
-  }));
+  });
 
   const obj = {
     toString() { throw new Error('toString'); },
@@ -58,11 +58,6 @@ test(function() {
   };
   const sym = Symbol();
   assert.throws(() => params.get(obj), /^Error: toString$/);
-  assert.throws(
-    () => params.get(sym),
-    common.engineSpecificMessage({
-      v8: /^TypeError: Cannot convert a Symbol value to a string$/,
-      chakracore: /^TypeError: Object doesn't support property or method 'ToString'/
-    })
-  );
+  assert.throws(() => params.get(sym),
+                /^TypeError: Cannot convert a Symbol value to a string$/);
 }
