@@ -1,3 +1,4 @@
+// Flags: --expose-internals
 'use strict';
 const common = require('../common');
 const fixtures = require('../common/fixtures');
@@ -18,25 +19,17 @@ async function testBreakpointOnStart(session) {
     { 'method': 'Debugger.setPauseOnExceptions',
       'params': { 'state': 'none' } },
     { 'method': 'Debugger.setAsyncCallStackDepth',
-      'params': { 'maxDepth': 0 } }
-  ];
-
-  if (!common.isChakraEngine) {
-    commands.push(
-      { 'method': 'Profiler.enable' },
-      { 'method': 'Profiler.setSamplingInterval',
-        'params': { 'interval': 100 } });
-  }
-
-  commands.push(
+      'params': { 'maxDepth': 0 } },
+    { 'method': 'Profiler.enable' },
+    { 'method': 'Profiler.setSamplingInterval',
+      'params': { 'interval': 100 } },
     { 'method': 'Debugger.setBlackboxPatterns',
       'params': { 'patterns': [] } },
-    { 'method': 'Runtime.runIfWaitingForDebugger' });
+    { 'method': 'Runtime.runIfWaitingForDebugger' }
+  ];
 
   await session.send(commands);
-  // ChakraCore stops at the first line of source, not
-  // the first line in a file
-  await session.waitForBreakOnLine(common.isChakraEngine ? 21 : 0, script);
+  await session.waitForBreakOnLine(0, script);
 }
 
 
