@@ -74,20 +74,27 @@ def ExpandConstants(lines, constants):
 
 
 def ExpandMacros(lines, macros):
+  def expander(s):
+    return ExpandMacros(s, macros)
   for name, macro in macros.items():
-    start = lines.find(name + '(', 0)
-    while start != -1:
+    name_pattern = re.compile("\\b%s\\(" % name)
+    pattern_match = name_pattern.search(lines, 0)
+    while pattern_match is not None:
       # Scan over the arguments
-      assert lines[start + len(name)] == '('
       height = 1
-      end = start + len(name) + 1
+      start = pattern_match.start()
+      end = pattern_match.end()
+      assert lines[end - 1] == '('
       last_match = end
-      arg_index = 0
-      mapping = { }
+      arg_index = [0]  # Wrap state into array, to work around Python "scoping"
+      mapping = {}
       def add_arg(str):
         # Remember to expand recursively in the arguments
-        replacement = ExpandMacros(str.strip(), macros)
-        mapping[macro.args[arg_index]] = replacement
+        if arg_index[0] >= len(macro.args):
+          return
+        replacement = expander(str.strip())
+        mapping[macro.args[arg_index[0]]] = replacement
+        arg_index[0] += 1
       while end < len(lines) and height > 0:
         # We don't count commas at higher nesting levels.
         if lines[end] == ',' and height == 1:
@@ -100,10 +107,13 @@ def ExpandMacros(lines, macros):
         end = end + 1
       # Remember to add the last match.
       add_arg(lines[last_match:end-1])
+      if arg_index[0] < len(macro.args) -1:
+        lineno = lines.count(os.linesep, 0, start) + 1
+        raise Exception('line %s: Too few arguments for macro "%s"' % (lineno, name))
       result = macro.expand(mapping)
       # Replace the occurrence of the macro with the expansion
       lines = lines[:start] + result + lines[end:]
-      start = lines.find(name + '(', start)
+      pattern_match = name_pattern.search(lines, start + len(result))
   return lines
 
 
@@ -163,19 +173,6 @@ def ReadMacros(lines):
           raise Exception("Illegal line: " + line)
   return (constants, macros)
 
-TEMPLATE_FOR_NAMESPACE = """
-namespace {namespace} {{
-{definitions}
-}} // namespace {namespace}
-"""
-
-ONE_BYTE_STRING_FOR_NAMESPACE = """
-static const uint8_t raw_{var}[] = {{ {data} }};
-"""
-
-TWO_BYTE_STRING_FOR_NAMESPACE = """
-static const uint16_t raw_{var}[] = {{ {data} }};
-"""
 
 TEMPLATE = """
 #include "node.h"
@@ -188,7 +185,11 @@ namespace node {{
 
 {definitions}
 
-v8::Local<v8::String> MainSource(Environment* env) {{
+v8::Local<v8::String> LoadersBootstrapperSource(Environment* env) {{
+  return internal_bootstrap_loaders_value.ToStringChecked(env->isolate());
+}}
+
+v8::Local<v8::String> NodeBootstrapperSource(Environment* env) {{
   return internal_bootstrap_node_value.ToStringChecked(env->isolate());
 }}
 
@@ -235,31 +236,17 @@ CHECK(target->Set(env->context(),
 def Render(var, data):
   # Treat non-ASCII as UTF-8 and convert it to UTF-16.
   if any(ord(c) > 127 for c in data):
-    template = TWO_BYTE_TEMPLATE
+    template = TWO_BYTE_STRING
     data = map(ord, data.decode('utf-8').encode('utf-16be'))
     data = [data[i] * 256 + data[i+1] for i in xrange(0, len(data), 2)]
     data = ToCArray(data)
   else:
-    template = ONE_BYTE_TEMPLATE
+    template = ONE_BYTE_STRING
     data = ToCString(data)
   return template.format(var=var, data=data)
 
 
-
-NODE_NATIVES_MAP = """\
-  V({escaped_id}) \\
-"""
-
-
-SOURCES = """\
-static const uint8_t {escaped_id}_name[] = {{
-{name}}};
-static const uint8_t {escaped_id}_data[] = {{
-{data}}};
-"""
-
-
-def JS2C(source, target, namespace):
+def JS2C(source, target):
   modules = []
   consts = {}
   macros = {}
@@ -288,6 +275,11 @@ def JS2C(source, target, namespace):
     if '/' in name or '\\' in name:
       name = '/'.join(re.split('/|\\\\', name)[1:])
 
+    # if its a gypi file we're going to want it as json
+    # later on anyway, so get it out of the way now
+    if name.endswith(".gypi"):
+      lines = re.sub(r'#.*?\n', '', lines)
+      lines = re.sub(r'\'', '"', lines)
     name = name.split('.', 1)[0]
     var = name.replace('-', '_').replace('/', '_')
     key = '%s_key' % var
@@ -299,34 +291,14 @@ def JS2C(source, target, namespace):
 
   # Emit result
   output = open(str(target[0]), "w")
-  output.write(HEADER_TEMPLATE.format(definitions=''.join(definitions),
-                               initializers=''.join(initializers),
-                               namespace=namespace))
+  output.write(TEMPLATE.format(definitions=''.join(definitions),
+                               initializers=''.join(initializers)))
   output.close()
 
-
-NAMESPACE_SWITCH = "--namespace="
-
 def main():
-  global HEADER_TEMPLATE
-  global ONE_BYTE_TEMPLATE
-  global TWO_BYTE_TEMPLATE
-  i = 1
-  if sys.argv[i].startswith(NAMESPACE_SWITCH):
-    HEADER_TEMPLATE = TEMPLATE_FOR_NAMESPACE
-    ONE_BYTE_TEMPLATE = ONE_BYTE_STRING_FOR_NAMESPACE
-    TWO_BYTE_TEMPLATE = ONE_BYTE_STRING_FOR_NAMESPACE
-    namespace = sys.argv[i][len(NAMESPACE_SWITCH):]
-    i += 1
-  else:
-    HEADER_TEMPLATE = TEMPLATE
-    ONE_BYTE_TEMPLATE = ONE_BYTE_STRING
-    TWO_BYTE_TEMPLATE = TWO_BYTE_STRING
-    namespace = 'node'
-
-  natives = sys.argv[i]
-  source_files = sys.argv[(i + 1):]
-  JS2C(source_files, [natives], namespace)
+  natives = sys.argv[1]
+  source_files = sys.argv[2:]
+  JS2C(source_files, [natives])
 
 if __name__ == "__main__":
   main()
